ETAS_Boots 0.2.0This earthquake data catalog is an excerpt from the dataset "japan.quakes" in the ETAS package (Jalilian, 2019), excluding the last column "depth". Its space-time window covers \(128^\circ\)E to \(145^\circ\)E in longitude and \(27^\circ\)N to \(45^\circ\)N in latitude and the period from 1926-01-08 00:00:00 to 2007-12-29 23:59:59 (UTC). Note: The hypocenter depth of the earthquakes of interest is less than \(100\) km.
JPN_earthquakesAn object of class data.frame with 5 columns:
date: Occurrence date of earthquakes in the format "yyyy-mm-dd"
time: Occurrence time of earthquakes in the format "hh-mm-ss"
longitude: Longitude of the epicenter of earthquakes in decimal degrees
latitude: Latitude of the epicenter of earthquakes in decimal degrees
magnitude: Magnitude of earthquakes
Jalilian, A. (2019). ETAS: An R package for fitting the space-time ETAS model to earthquake data. Journal of Statistical Software, Code Snippets, 88(1), 1–39. doi:10.18637/jss.v088.c01.